%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% CalculateFits
% 
% Reference: Fetal/Juvenile Tumor Initiation (2010)
% Authors: Kini, L.G., Herrero-Jimenez P., Guitterez Jr E., Hensle, D.,
%    Kogel J., Kusko R., Rexer, K., Kurzweil, R., Gostjeva, E., 
%    Morgenthaler, S., and Thilly WG.
% Contact: Lohith Kini <lkini (AT) mit DOT edu>
% Version: 5.0
% Last modified: March 22, 2010
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [ CAL ] = CalcCAL( amax,m,n, F,f,mu,Ri,RA )
%CalcCAL Calculates CAL(g) for given model parameters based on model
%   equation in Kini et al (2010).
%
%   Input variables are model parameters:
%    amax, m, n and fit parameters F, f, mu, R_initiation and R_promotion

[G,A] = meshgrid(0:1:50,amax-floor(amax):1:amax);

if(m >= 2)
    Vobs = n*Ri^n*RA^m* A.^(n-1) .* 2.^G .* (2*(G-A+1).^(m-1) - (G-A).^(m-1)) .* exp(- RA^m * (G-A).^(m-1) .* 2.^(G-A) );
else
    Vobs = n*Ri^n*RA^m*log(2)* A.^(n-1) .* 2.^G .* exp(- RA^m * (G-A).^(m-1) .* 2.^(G-A) );
end

mask = zeros(floor(amax)+1,51);

for g = 0:1:50
    for a = 1:1:min(floor(amax),g)+1
        mask(a,g+1) = 1;
    end
end

Vobs = Vobs .* mask;

Vobs = sum(Vobs,1);
Pobs = 1 - exp(-Vobs); 

int_Vobs = cumsum(Vobs);

CAL = F ./ (F + (1-F)*exp(1/f*int_Vobs)) .* Pobs;

% Optional script to plot CAL(g) per 100,000 from g = [0 .. 50]
% semilogy(0:1:50,CAL*1E5,'s-')
% grid on
% legend('CAL(g)')

end
